@@ -44,7 +44,8 @@ from yubiauth.util.rest import (REST_API, Route, json_response, json_error,
                                 extract_params)
 from yubiauth import settings
 
-import logging as log
+import logging
+log = logging.getLogger(__name__)
 
 SESSION_COOKIE = 'YubiAuth-Session'
 SESSION_HEADER = 'X-%s' % SESSION_COOKIE
@@ -54,8 +55,8 @@ REVOKE_ATTRIBUTE = '_REVOKE'
 @wsgify.middleware
 def ClientMiddleware(request, app):
     # Allow the session ID to be provided as a header or cookie.
-    if not SESSION_COOKIE in request.cookies and \
-            SESSION_HEADER in request.headers:
+    # Header takes precedence over cookie.
+    if SESSION_HEADER in request.headers:
         request.cookies[SESSION_COOKIE] = request.headers[SESSION_HEADER]
     if 'yubiauth.client' in request.environ:
         return app
@@ -96,7 +97,7 @@ def require_session(func=None, **kwargs):
                 request.environ['yubiauth.user'] = \
                     client.auth.get_user(user_id)
             except Exception, e:
-                log.warn(e)
+                log.exception('Session required!')
                 if error_handler:
                     return error_handler(request, e)
                 elif hasattr(self, 'session_required'):
